@@ -8,6 +8,8 @@
     data_list <- .manager_recv(manager)
     success <- rep(TRUE, length(data_list))
     for(i in seq_along(data_list)){
+        ## each result is a list containing the element value passed
+        ## in `.send` and possibly other elements used by the backend
         d <- data_list[[i]]
 
         value <- d$value$value
@@ -203,9 +205,11 @@
 
     ## worker options
     OPTIONS <- .workerOptions(
-        bplog(BPPARAM), bpstopOnError(BPPARAM),
-        timeout=bptimeout(BPPARAM),
-        exportglobals=bpexportglobals(BPPARAM),
+        log = bplog(BPPARAM),
+        threshold = bpthreshold(BPPARAM),
+        stop.on.error = bpstopOnError(BPPARAM),
+        timeout = bptimeout(BPPARAM),
+        exportglobals = bpexportglobals(BPPARAM),
         force.GC = bpforceGC(BPPARAM)
     )
 
