@@ -5,5 +5,5 @@ ${RPROG:-R} --vanilla <<EOF > ${OUT:-/dev/null} 2>&1
 loadNamespace("Rmpi")
 loadNamespace("snow")
 
-BiocParallel::bprunMPIslave()
+BiocParallel::bprunMPIworker()
 EOF
